==> digiclockwdg_0.4.0.tar.gz: digiclockwdg-0.4.0/src/digiclock_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation type="unfinished">Настройки DigiClock</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished">Высота</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation type="unfinished">Цвет Цифр</translation>
    </message>	
    <message>
        <source>24H</source>
        <translation type="unfinished">24 часа</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished">12 часов (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished">военный</translation>
    </message>	
    <message>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="268"/>		
        <translation type="unfinished">Qt</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="88"/>	
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="98"/>	
        <source>Default (LCD)</source>
        <translation type="unfinished">Исходный (LCD)</translation>
    </message>	
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished">О программе DigiClock</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="118"/>	
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="136"/>	
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="155"/>	
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished">Отображение</translation>
    </message>		
    <message>
        <source>Transparency</source>	
        <translation type="unfinished">Прозрачность</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished">Опции</translation>
    </message>	
    <message>
        <source>Format</source>
        <translation type="unfinished">Формат</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished">cекунды</translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation type="unfinished">мигание</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation type="unfinished">Часовой пояс</translation>
    </message>	
    <message>
        <source>Show City</source>
        <translation type="unfinished">Городs</translation>
    </message>
    <message>
        <source>Open Clock app on Click</source>
        <translation type="unfinished">Открывать часы по клику</translation>
    </message>
    <message>
        <source>Rotate on Accel</source>
        <translation type="unfinished">Автоповорот</translation>
    </message>
    <message>
        <source>DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developed with</source>
        <translation type="unfinished">Написано на</translation>
    </message>
    <message>
        <source>Desktop widget, showing digital time</source>
        <translation type="unfinished">Виджет, отображающий время в цифровом формате</translation>
    </message>
    <message>
        <source>Send reports to:</source>
        <translation type="unfinished">Письмо автору:</translation>
    </message>

</context>
</TS>

==> digiclockwdg_0.4.1.tar.gz: digiclockwdg-0.4.1/src/digiclock_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation type="unfinished">Настройки DigiClock</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished">Высота</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation type="unfinished">Цвет Цифр</translation>
    </message>	
    <message>
        <source>24H</source>
        <translation type="unfinished">24 часа</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished">12 часов (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished">военный</translation>
    </message>	
    <message>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="268"/>		
        <translation type="unfinished">Qt</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="88"/>	
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="98"/>	
        <source>Default (LCD)</source>
        <translation type="unfinished">Исходный (LCD)</translation>
    </message>	
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished">О программе DigiClock</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="118"/>	
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="136"/>	
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="155"/>	
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished">Отображение</translation>
    </message>		
    <message>
        <source>Transparency</source>	
        <translation type="unfinished">Прозрачность</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished">Опции</translation>
    </message>	
    <message>
        <source>Format</source>
        <translation type="unfinished">Формат</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished">cекунды</translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation type="unfinished">мигание</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation type="unfinished">Часовой пояс</translation>
    </message>	
    <message>
        <source>Show City name</source>
        <translation type="unfinished">Название Города</translation>
    </message>
    <message>
        <source>Open Clock app on Click</source>
        <translation type="unfinished">Открывать часы по клику</translation>
    </message>
    <message>
        <source>Enable Autorotation</source>
        <translation type="unfinished">Разрешить Автоповорот</translation>
    </message>
    <message>
        <source>DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developed with</source>
        <translation type="unfinished">Написано на</translation>
    </message>
    <message>
        <source>Desktop widget, showing digital time</source>
        <translation type="unfinished">Виджет, отображающий время в цифровом формате</translation>
    </message>
    <message>
        <source>Send reports to:</source>
        <translation type="unfinished">Письмо автору:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation type="unfinished">Вращение</translation>
    </message>
    <message>
        <source>Fixed Corner</source>
        <translation type="unfinished">Зафиксировать Угол</translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished">Верхний Левый</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished">Верхний Правый</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished">Нижний левый</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished">Нижний Правый</translation>
    </message>	
</context>
</TS>
